aboutsummaryrefslogtreecommitdiff
path: root/src/pipeline.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/pipeline.h')
-rw-r--r--src/pipeline.h12
1 files changed, 8 insertions, 4 deletions
diff --git a/src/pipeline.h b/src/pipeline.h
index 3b9b75c..2e5fb0c 100644
--- a/src/pipeline.h
+++ b/src/pipeline.h
@@ -232,12 +232,16 @@ class Pipeline {
/// buffer bound.
Buffer* GetIndexBuffer() const { return index_buffer_; }
- /// Adds |buf| to the pipeline at the given |descriptor_set| and |binding|.
- void AddBuffer(Buffer* buf, uint32_t descriptor_set, uint32_t binding);
+ /// Adds |buf| of |type |to the pipeline at the given |descriptor_set|
+ /// and |binding|.
+ void AddBuffer(Buffer* buf,
+ BufferType type,
+ uint32_t descriptor_set,
+ uint32_t binding);
/// Adds |buf| to the pipeline at the given |arg_name|.
- void AddBuffer(Buffer* buf, const std::string& arg_name);
+ void AddBuffer(Buffer* buf, BufferType type, const std::string& arg_name);
/// Adds |buf| to the pipeline at the given |arg_no|.
- void AddBuffer(Buffer* buf, uint32_t arg_no);
+ void AddBuffer(Buffer* buf, BufferType type, uint32_t arg_no);
/// Returns information on all buffers in this pipeline.
const std::vector<BufferInfo>& GetBuffers() const { return buffers_; }